@@ -7,7 +7,7 @@ RDF::Trine::Serializer::Turtle - Turtle Serializer
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::Turtle version 0.132_01
+This document describes RDF::Trine::Serializer::Turtle version 0.132_02
 
 =head1 SYNOPSIS
 
@@ -52,10 +52,10 @@ use RDF::Trine::Namespace qw(rdf);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.132_01';
+	$VERSION	= '0.132_02';
 	$RDF::Trine::Serializer::serializer_names{ 'turtle' }	= __PACKAGE__;
 	$RDF::Trine::Serializer::format_uris{ 'http://www.w3.org/ns/formats/Turtle' }	= __PACKAGE__;
-	foreach my $type (qw(application/x-turtle application/turtle text/turtle)) {
+	foreach my $type (qw(application/x-turtle application/turtle text/turtle text/rdf+n3)) {
 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
 	}
 }
